@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2006, 2007, 2008, 2010, 2011, 2013 XStream Committers.
+ * Copyright (C) 2006, 2007, 2008, 2010, 2011, 2013, 2014, 2015 XStream Committers.
  * All rights reserved.
  *
  * The software in this package is published under the terms of the BSD
@@ -407,7 +407,7 @@ public class CGLIBEnhancedConverter extends SerializableConverter {
         if (result == null) {
             result = create(enhancer, callbacks, useFactory);
         }
-        return serializationMethodInvoker.callReadResolve(result);
+        return serializationMembers.callReadResolve(result);
     }
 
     private void readCallback(HierarchicalStreamReader reader, UnmarshallingContext context,
@@ -438,7 +438,8 @@ public class CGLIBEnhancedConverter extends SerializableConverter {
         return typeHierarchy;
     }
 
-    private Object readResolve() {
+    protected Object readResolve() {
+        super.readResolve();
         fieldCache = new HashMap();
         return this;
     }
